s6: the s6-svstat program
Keywords: s6 command s6-svstat servicedir checking supervision s6-supervise

s6
Software
skarnet.org

# The s6-svstat program

s6-svstat prints a short, human-readable summary of the state of a process monitored by s6-supervise.

## Interface

         s6-svstat [ -n ] servicedir

s6-svstat gives information about the process being monitored at the servicedir service directory, then exits 0. The information includes the following:

- whether the process is up or down, and if it's up, the number of seconds that it has been up.
- the process' pid, if it is up, or its last exit code or terminating signal, if it is down
- what its default state is, if it is different from its current state
- the number of seconds since it last changed states
- if the current state is transient and will change as soon as the kernel's scheduler picks up s6-supervise
- whether the service is ready, as notified by the daemon itself, and if it is, the number of seconds that it has been. A service reported as down and ready simply means that it is ready to be brought up. A service is down and not ready when it is in the cleanup phase, i.e. the `./finish` script is still being executed.

## Options

- `-n` : if the monitored process has been killed by a signal, print the signal number. By default, a symbolic name for the signal will be printed instead.